@@ -504,7 +504,8 @@ the empty string."
                            nil
                            0
                            nil
-                           'bookmark-history)))
+                           'bookmark-history
+			   default)))
     (if (string-equal "" str)
         (list default)
       (list str))))
