@@ -139,13 +139,6 @@
 
 ;;; Utility functions:
 
-;; I think this belongs in a library.  Which one?  #### Please advise.
-(defun in-user-init-directory (file-name-form)
-  (substitute-in-file-name
-   (expand-file-name (concat "~" init-file-user
-			     user-init-directory
-			     (eval file-name-form)))))
-;; Ditto.
 (defun wwi-with-open-database
   (db-file-name db-sym db-thunk &optional type subtype access mode)
   "Open the database DB-FILE-NAME, binding the resultant object to
@@ -185,7 +178,7 @@ Please read the documentation to `toggle-where-was-i'."
   :require 'where-was-i-db
   :group 'where-was-i)
 
-(defcustom where-was-i-db (in-user-init-directory ".wwi.db")
+(defcustom where-was-i-db (expand-file-name ".wwi.db" user-init-directory)
   "Location and filename of the `where-was-i-db' database file.
 The default location is usually the right place for it."
   :type 'file
